import {randomUserData, type CreateUserData, type UserData, randomString} from './rand';

const lpad = (value: string, charCount: number, padChar: string): string => {
  expect(padChar).to.have.length(1);
  let modifiedValue: string = value;
  while (modifiedValue.length < charCount) {
    modifiedValue = padChar + modifiedValue;
  }
  return modifiedValue;
};

const school = 'school1';

export const createUser = (userData?: CreateUserData): Promise<UserData> => {
  const user = userData || randomUserData();
  let interceptKey = `listViewConf-${randomString(16)}`;
  cy.intercept('GET', '/ucsschool/bff-users/v1/pageconf/listView').as(interceptKey);
  cy.visit('/');
  cy.wait(`@${interceptKey}`).its('response.statusCode').should('eq', 200);
  cy.get('main.listView')
    .should('be.visible');
  cy.get('.uStandbyWrapper')
    .should('not.exist');
  interceptKey = `addViewConf-${randomString(16)}`;
  cy.intercept('GET', '/ucsschool/bff-users/v1/pageconf/addView').as(interceptKey);
  cy.contains('.uGrid__header .uButton', 'Hinzufügen')
    .click();
  cy.wait(`@${interceptKey}`).its('response.statusCode').should('eq', 200);
  cy.get('main.editView')
    .should('be.visible');
  cy.get('.uStandbyWrapper')
    .should('not.exist');
  cy.get('input[name="firstname"]')
    .type(user.firstname, {scrollBehavior: 'center'});
  cy.get('input[name="lastname"]')
    .type(user.lastname, {scrollBehavior: 'center'});
  if (user.username) {
    cy.get('input[name="name"]')
      .type(user.username, {scrollBehavior: 'center'});
  }
  if (user.birthday) {
    const birthdayString = [
      lpad(String(user.birthday[0]), 2, '0'),
      lpad(String(user.birthday[1]), 2, '0'),
      lpad(String(user.birthday[2]), 2, '0'),
    ].join('-');
    cy.get('input[name="birthday"]').type(birthdayString, {scrollBehavior: 'center'});
  }
  if (user.email) {
    cy.get('input[name="email"]').type(user.email, {scrollBehavior: 'center'});
  }
  cy.get('input[name="password"]').type('univention', {scrollBehavior: 'center'});

  interceptKey = `schoolClasses-${randomString(16)}`;
  cy.intercept('GET', '/ucsschool/bff-users/v1/school_class?school=*').as(interceptKey);
  cy.get('input[name="school"]').type(school).type('{enter}');
  cy.wait(`@${interceptKey}`).its('response.statusCode').should('eq', 200);

  const role = {
    student: 'Lernende',
    genericUser: 'Nutzende',
    teacher: 'Lehrkraft',
    schoolAdmin: 'Schuladmins',
    technicalAdmin: 'Fachliche Leitstelle',
  }[user.role];
  cy.get('input[name="role"]').type(role);

  let resolvePromise: null | ((thenableOrResult?: unknown) => void) = null;
  const promise = new Cypress.Promise(resolve => {
    resolvePromise = resolve;
  });

  // Random alias name since this function might get called multiple times
  // in the same test and with a static alias name I got wrong expected responses
  // (response was from previous `createUser` call).
  interceptKey = `createUser-${randomString(16)}`;
  cy.intercept('POST', '/ucsschool/bff-users/v1/users/').as(interceptKey);
  cy.contains('.listView__header__buttons .uButton', 'Benutzer anlegen')
    .click();
  cy.get('.uStandbyWrapper')
    .should('be.visible');
  cy.wait(`@${interceptKey}`).then(({response}) => {
    expect(response?.statusCode).to.equal(201);
    const createdUser = {
      ...user,
      username: response?.body.name,
      email: response?.body.email,
    };
    cy.get('.uConfirmDialog input[name="saveSuccessModal_email"]')
      .should('have.value', response?.body.email);
    cy.get('.uConfirmDialog input[name="saveSuccessModal_username"]')
      .should('have.focus')
      .should('have.value', response?.body.name);

    cy.get('.uStandbyWrapper').should('have.length', 0);
    cy.get('.uConfirmDialog').should('be.visible');
    cy.get('.uConfirmDialog__buttons .uButton').eq(0).click();
    cy.url().should('eq', `${Cypress.config().baseUrl}/`);
    // the next two assertions make sure the tests work in firefox: Because
    //  firefox will cause the application to trigger a NetworkError if an
    //  on-going AJAX request is aborted. So we will wait for all AJAX
    //  requests to finish before considering this step to be finished.
    cy.get('main.listView').should('be.visible');
    cy.get('.uStandbyWrapper').should('have.length', 0);
    resolvePromise?.(createdUser);
  });
  return promise;
};

export const createMultipleUsers = (users: number | UserData[]): Promise<UserData[]> => {
  let usersList: UserData[] = [];
  if (typeof users === 'number') {
    for (let i = 0; i < users; i++) {
      usersList.push(randomUserData());
    }
  } else {
    usersList = users;
  }
  return Cypress.Promise.all(usersList.map(createUser));
};
