import type {UserDetailResponseModel} from '@/helpers/models';

export const userDetailResponseModel: UserDetailResponseModel = {
  url: '',
  allowedActions: ['save'],
  pages: [
    {
      label: 'General',
      name: 'general',
      fieldsets: [
        {
          label: 'Basic settings',
          name: 'general__basic',
          rows: [
            [
              {
                type: 'UInputText',
                props: {
                  name: 'firstname',
                  label: 'First name',
                  required: false,
                  access: 'write',
                },
              },
              {
                type: 'UInputText',
                props: {
                  name: 'lastname',
                  label: 'Last name',
                  required: true,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputText',
                props: {
                  name: 'divisNameAffix',
                  label: 'Name affix',
                  required: false,
                },
              },
              {
                type: 'UInputText',
                props: {
                  name: 'name',
                  label: 'Username',
                  required: true,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputPassword',
                props: {
                  name: 'password',
                  label: 'Password',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputText',
                props: {
                  name: 'email',
                  label: 'Primary mail address',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputCheckbox',
                props: {
                  label: 'Disabled',
                  name: 'disabled',
                  required: false,
                  access: 'write',
                },
              },
            ],
          ],
        },
        {
          label: 'Groups',
          name: 'general__groups',
          rows: [
            [
              {
                type: 'UMultiSelect',
                props: {
                  name: 'groups',
                  label: 'Groups',
                  hideCheckboxColumn: true,
                  columns: [
                    {
                      label: 'Group',
                      attribute: 'group',
                      formatter: {type: 'linkRender'},
                      sortFormatter: {type: 'linkSort'},
                    },
                  ],
                  rows: [
                    {
                      id: 'group1',
                      attributes: {
                        group: {
                          value: {
                            url: 'https://someurl',
                            text: 'linktext',
                          },
                          access: 'read',
                        },
                      },
                    },
                  ],
                },
              },
            ],
          ],
        },
        {
          label: 'Personal information',
          name: 'general__personalInformation',
          rows: [
            [
              {
                type: 'UInputText',
                props: {
                  name: 'divisNickname',
                  label: 'Nickname',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputText',
                props: {
                  name: 'displayName',
                  label: 'Display name',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputDate',
                props: {
                  name: 'birthday',
                  label: 'Birthday',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UMultiInput',
                props: {
                  name: 'e-mail',
                  label: 'E-mails',
                  required: false,
                  subElements: [
                    {
                      type: 'UInputText',
                      props: {
                        name: 'e-mail__mail',
                        label: 'E-mails',
                      },
                    },
                  ],
                },
              },
            ],
          ],
        },
        {
          label: 'UCS@school',
          name: 'general__ucs@school',
          rows: [
            [
              {
                type: 'UComboBox',
                props: {
                  name: 'school',
                  label: 'Primary school',
                  options: [
                    {
                      value: 'school1',
                      label: 'School 1',
                    }, {
                      value: 'school2',
                      label: 'School 2',
                    },
                  ],
                  required: true,
                },
              },
            ],
            [
              {
                type: 'UMultiSelect',
                props: {
                  name: 'schools',
                  label: 'Schools',
                  columns: [
                    {
                      label: 'Select all',
                      attribute: 'label',
                    },
                  ],
                  rows: [
                    {
                      id: 'school1',
                      attributes: {
                        label: {
                          value: 'School 1',
                          access: 'read',
                        },
                      },
                    },
                    {
                      id: 'school2',
                      attributes: {
                        label: {
                          value: 'School 2',
                          access: 'read',
                        },
                      },
                    },
                  ],
                  required: true,
                },
              },
            ],
            [
              {
                type: 'UMultiInput',
                props: {
                  name: 'schoolSpecificValidity',
                  label: 'School specific validities',
                  required: false,
                  subElements: [
                    {
                      type: 'UInputText',
                      props: {
                        name: 'schoolSpecificValidity__element',
                        label: 'School specific validity',
                      },
                    },
                  ],
                },
              },
            ],
            [
              {
                type: 'UComboBox',
                props: {
                  name: 'role',
                  label: 'Role',
                  required: true,
                  options: [
                    {
                      value: 'student',
                      label: 'Lernende',
                    },
                    {
                      value: 'generic_user',
                      label: 'Nutzende',
                    },
                    {
                      value: 'teacher',
                      label: 'Lehrkraft',
                    },
                    {
                      value: 'school_admin',
                      label: 'Schuladmins',
                    },
                    {
                      value: 'technical_admin',
                      label: 'Fachliche Leitstelle',
                    },
                  ],
                },
              },
            ],
            [
              {
                type: 'UComboBox',
                props: {
                  name: 'sourceUID',
                  label: 'Source UID',
                  options: [
                    {
                      label: 'DiViS',
                      value: 'DiViS',
                    },
                    {
                      label: 'Manuell',
                      value: 'Manuell',
                    },
                  ],
                  required: false,
                },
              },
              {
                type: 'UInputText',
                props: {
                  name: 'recordUID',
                  label: 'Record UID',
                  required: false,
                },
              },
            ],
            [
              {
                type: 'UInputDate',
                props: {
                  name: 'ucsschoolPurgeTimestamp',
                  label: 'Scheduled deletion date',
                  required: false,
                },
              },
            ],
          ],
        },
      ],
    },
    {
      label: 'Account',
      name: 'account',
      fieldsets: [
        {
          label: 'General',
          name: 'account__general',
          rows: [
            [
              {
                type: 'UInputDate',
                props: {
                  name: 'createTimestamp',
                  label: 'Creation date',
                  required: false,
                },
              },
            ],
            [
              {
                type: 'UInputDate',
                props: {
                  name: 'modifyTimestamp',
                  label: 'Date of last change',
                  required: false,
                },
              },
            ],
          ],
        },
        {
          label: 'Deactivation',
          name: 'account__deactivation',
          rows: [
            [
              {
                type: 'UInputDate',
                props: {
                  name: 'expirationDate',
                  label: 'Expiration date',
                  required: false,
                },
              },
            ],
            [
              {
                type: 'UInputCheckbox',
                props: {
                  name: 'disabled',
                  label: 'Disabled',
                  required: false,
                },
              },
            ],
          ],
        },
        {
          label: 'Locked login',
          name: 'account__lockedLogin',
          rows: [
            [
              {
                type: 'UInputCheckbox',
                props: {
                  name: 'pwdChangeNextLogin',
                  label: 'User has to change password on next login',
                  required: false,
                },
              },
            ],
          ],
        },
        {
          label: 'Activation',
          name: 'account__activation',
          rows: [
            [
              {
                type: 'UInputDate',
                props: {
                  name: 'accountActivationDate',
                  label: 'Activation date',
                  required: false,
                },
              },
            ],
          ],
        },
        {
          label: 'Password recovery',
          name: 'account__passwordRecovery',
          rows: [
            [
              {
                type: 'UInputText',
                props: {
                  name: 'PasswordRecoveryEmail',
                  label: 'Password recovery e-mail',
                  required: false,
                },
              },
            ],
            [
              {
                type: 'UInputCheckbox',
                props: {
                  name: 'PasswordRecoveryEmailVerified',
                  label: 'Is the password recovery e-mail verified?',
                  required: false,
                },
              },
            ],
          ],
        },
        {
          label: 'WLAN',
          name: 'account__wlan',
          rows: [
            [
              {
                type: 'UInputCheckbox',
                props: {
                  name: 'networkAccess',
                  label: 'WLAN (Radius) usage',
                  required: false,
                },
              },
            ],
          ],
        },
        {
          label: 'SAML settings',
          name: 'account__samlSettings',
          rows: [
            [
              {
                type: 'UMultiSelect',
                props: {
                  name: 'serviceprovider',
                  label: 'SAML service provider',
                  required: false,
                  columns: [
                    {
                      label: 'Select all',
                      attribute: 'label',
                    },
                  ],
                  rows: [
                    {
                      id: 'sp1',
                      attributes: {
                        label: {
                          value: 'Service provider 1',
                          access: 'read',
                        },
                      },
                    },
                    {
                      id: 'sp2',
                      attributes: {
                        label: {
                          value: 'Service provider 2',
                          access: 'read',
                        },
                      },
                    },
                    {
                      id: 'sp3',
                      attributes: {
                        label: {
                          value: 'Service provider 3',
                          access: 'read',
                        },
                      },
                    },
                  ],
                },
              },
            ],
          ],
        },
      ],
    },
  ],
  values: {
    'firstname': 'firstname',
    'lastname': 'lastname',
    'divisNameAffix': '',
    'name': 'username',
    'password': '',
    'email': '',
    'disabled': false,
    'divisNickname': 'nickname',
    'displayName': 'display name',
    'birthday': '2020-05-03',
    'e-mail': ['mustermann@max.de', 'max@muster.de'],
    'school': 'school1',
    'schools': ['school1'],
    'role': 'student',
    'groups': [],
    'sourceUID': '',
    'recordUID': '',
    'ucsschoolPurgeTimestamp': '',
    'createTimestamp': '',
    'modifyTimestamp': '',
    'expirationDate': '',
    'pwdChangeNextLogin': false,
    'accountActivationDate': '',
    'PasswordRecoveryEmail': '',
    'PasswordRecoveryEmailVerified': false,
    'networkAccess': false,
    'serviceprovider': [],
    'schoolSpecificValidity': ['Stadtteilschule Bergstedt: 31.01.2022 - 01.07.2023'],
  },
};
